@@ -267,10 +267,24 @@ class ClusterTemplatesController(base.Controller):
         "different storage driver, such as overlay2. overlay2 will be set "
         "as the default storage driver from Victoria cycle in Magnum.")
 
+    _coreos_deprecation_note = (
+        "The coreos driver is deprecated in favor of the fedora_coreos "
+        "driver. Please migrate to the fedora_coreos driver. coreos "
+        "driver will be removed in a future Magnum version.")
+
     _fedora_atomic_deprecation_note = (
         "The fedora_atomic driver is deprecated in favor of the fedora_coreos "
         "driver. Please migrate to the fedora_coreos driver. fedora_atomic "
-        "driver will be remove in a future Magnum version.")
+        "driver will be removed in a future Magnum version.")
+
+    _fedora_ironic_deprecation_note = (
+        "The fedora ironic driver is deprecated. "
+        "The driver will be removed in a future Magnum version.")
+
+    _docker_swarm_deprecation_note = (
+        "The swarm coe is deprecated as the fedora_atomic distro is EOL. "
+        "Please migrate to using the kubernetes coe. "
+        "The swarm coe will be removed in a future Magnum version.")
 
     def _generate_name_for_cluster_template(self, context):
         """Generate a random name like: zeta-22-model."""
@@ -432,6 +446,25 @@ class ClusterTemplatesController(base.Controller):
                           DeprecationWarning)
             LOG.warning(self._fedora_atomic_deprecation_note)
 
+        if (cluster_template_dict['coe'] == 'kubernetes' and
+                cluster_template_dict['cluster_distro'] == 'coreos'):
+            warnings.warn(self._coreos_deprecation_note,
+                          DeprecationWarning)
+            LOG.warning(self._coreos_deprecation_note)
+
+        if (cluster_template_dict['coe'] == 'kubernetes' and
+                cluster_template_dict['cluster_distro'] == 'fedora' and
+                cluster_template_dict['server_type'] == 'bm'):
+            warnings.warn(self._fedora_ironic_deprecation_note,
+                          DeprecationWarning)
+            LOG.warning(self._fedora_ironic_deprecation_note)
+
+        if (cluster_template_dict['coe'] == 'swarm' or
+                cluster_template_dict['coe'] == 'swarm-mode'):
+            warnings.warn(self._docker_swarm_deprecation_note,
+                          DeprecationWarning)
+            LOG.warning(self._docker_swarm_deprecation_note)
+
         # NOTE(yuywz): We will generate a random human-readable name for
         # cluster_template if the name is not specified by user.
         arg_name = cluster_template_dict.get('name')
